import os
from datetime import datetime, time

from nose.tools import eq_
from pyexcel_io._compact import OrderedDict

from pyexcel_xlsx import get_data


def test_reading():
    data = get_data(
        os.path.join("tests", "fixtures", "date_field.xlsx"),
        library="pyexcel-xlsx",
        skip_hidden_row_and_column=False
    )
    expected = OrderedDict()
    expected.update(
        {
            "Sheet1": [
                ["Date", "Time"],
                [
                    datetime(year=2014, month=12, day=25),
                    time(hour=11, minute=11, second=11),
                ],
                [
                    datetime(2014, 12, 26, 0, 0),
                    time(hour=12, minute=12, second=12),
                ],
                [
                    datetime(2015, 1, 1, 0, 0),
                    time(hour=13, minute=13, second=13),
                ],
                [
                    datetime(year=1899, month=12, day=30),
                    datetime(1899, 12, 30, 0, 0),
                ],
            ]
        }
    )
    expected.update({"Sheet2": []})
    expected.update({"Sheet3": []})
    eq_(data, expected)



import os

from base import PyexcelWriterBase, PyexcelHatWriterBase
from pyexcel_xlsx import get_data
from pyexcel_xlsx.xlsxw import XLSXWriter as Writer


class TestNativeXLSXWriter:
    def test_write_book(self):
        self.content = {
            "Sheet1": [[1, 1, 1, 1], [2, 2, 2, 2], [3, 3, 3, 3]],
            "Sheet2": [[4, 4, 4, 4], [5, 5, 5, 5], [6, 6, 6, 6]],
            "Sheet3": [[u"X", u"Y", u"Z"], [1, 4, 7], [2, 5, 8], [3, 6, 9]],
        }
        self.testfile = "writer.xlsx"
        writer = Writer(self.testfile, "xlsx")
        writer.write(self.content)
        writer.close()
        content = get_data(self.testfile)
        for key in content.keys():
            content[key] = list(content[key])
        assert content == self.content

    def tearDown(self):
        if os.path.exists(self.testfile):
            os.unlink(self.testfile)


class TestxlsxnCSVWriter(PyexcelWriterBase):
    def setUp(self):
        self.testfile = "test.xlsx"
        self.testfile2 = "test.csv"

    def tearDown(self):
        if os.path.exists(self.testfile):
            os.unlink(self.testfile)
        if os.path.exists(self.testfile2):
            os.unlink(self.testfile2)


class TestxlsxHatWriter(PyexcelHatWriterBase):
    def setUp(self):
        self.testfile = "test.xlsx"

    def tearDown(self):
        if os.path.exists(self.testfile):
            os.unlink(self.testfile)
